<?php

/**
 * @file
 * Dynamic style template.
 * Will be parsed with actual theme settings into a cacheable css file.
 */

// Mini helper.
$tgs = function($s) {
  return theme_get_setting($s, 'bilderblock');
};

$logo = bilderblock::logoURL('logo');
$homeIcon = bilderblock::logoURL('home_icon');

?>
/**
 * Dynamic bilderblock styles.
 */

body.bilderblock-logo div#menu-logo > a:before {
  content: url(<?php print $logo; ?>);
}

<?php if ($content_max_width = $tgs('content_max_width')): ?>
/**
 * Set maximum content width to <?php print $content_max_width; ?> as configured,
 * but only in viewports with at least that size (overflow control).
 * @todo refactor as of #182.
 */
@media screen and (min-width: <?php print $content_max_width; ?>) {
  body > div#page > div#content-wrapper {
    max-width: <?php print $content_max_width; ?>;
  }
}
<?php endif; ?>

<?php if ($tgs('hover_enabled') || !$tgs('fx_hover_clear')) : ?>
/** Effects limited to no-touch desktop devices. **/
/* Overall filter animation speed. */
div.slide-container,
div#content-wrapper,
div.teaser-sidestrip-inner,
div.teaser-slide,
div.teaser-slide:after,
div.teaser-slide img {
  -moz-transition-duration: <?php print $tgs('fx_speed'); ?>ms;
  -webkit-transition-duration: <?php print $tgs('fx_speed'); ?>ms;
  -o-transition-duration: <?php print $tgs('fx_speed'); ?>ms;
  transition-duration: <?php print $tgs('fx_speed'); ?>ms;
}
<?php $opacity = $tgs('fx_opacity');
  if ($opacity != 100) : ?>
/* Opacity */
html:not(.touchevents) body.bilderblock-fx-opacity.bilderblock-fx-hover-clear div.slide-container:not(:focus):not(:hover),
html:not(.touchevents) body.bilderblock-fx-opacity:not(.bilderblock-fx-hover-clear) div.slide-container {
  opacity: <?php print $opacity / 100; ?>;
}
<?php endif;

// Prepare multiple filters.
// Since "filter" attributes mutually override, we have to prepare a chain.

$classes = $filters = array();

// 1. Desaturation:
$saturation = $tgs('fx_saturation');
if ($saturation != 100) {
  $classes[] = 'bilderblock-fx-saturation';
  $filters[] = "saturate({$saturation}%)";
}
// 2. Tint
if ($tint = $tgs('fx_tint')) {
  $classes[] = 'bilderblock-fx-tint';
  $filters[] = 'url(#bilderblock-filter-tint)';
}

if (
  ($classes = implode('.', $classes))
  &&
  ($filters = implode(' ', $filters))
) : ?>
html:not(.touchevents) body.<?php print $classes; ?>.bilderblock-fx-hover-clear div.slide-container:not(:focus):not(:hover) div.teaser-slide img,
html:not(.touchevents) body.<?php print $classes; ?>:not(.bilderblock-fx-hover-clear) div.teaser-slide img {
  -moz-filter: <?php print $filters; ?>;
  -o-filter: <?php print $filters; ?>;
  -webkit-filter: <?php print $filters; ?>;
  filter: <?php print $filters; ?>;
}
/* Override: Unpublished nodes */
html:not(.touchevents) body.<?php print $classes; ?>.bilderblock-fx-hover-clear div.slide-container.node-unpublished:not(:focus):not(:hover) div.teaser-slide img,
html:not(.touchevents) body.<?php print $classes; ?>:not(.bilderblock-fx-hover-clear) div.slide-container.node-unpublished div.teaser-slide img {
  -moz-filter: <?php print $filters; ?> invert(100%);
  -o-filter: <?php print $filters; ?> invert(100%);
  -webkit-filter: <?php print $filters; ?> invert(100%);
  filter: <?php print $filters; ?> invert(100%);
}
<?php endif; ?>

@media screen and (min-width: 961px) {

  /** Fixed menu/flyout sidebar for "desktop" and above. **/
  /* Sidebar container abstracts menu part from outer parts. */
  div#sidebar-container,
  /* Menu toggle switch in expanded menu. */
  div#menuswitch {
    width: <?php print $tgs('menu_expanded_width'); ?>;
  }
  /* Outer menu container. */
  div#menu {
    width: <?php print $tgs('menu_expanded_width'); ?>;
  }
  /* Outer container (default state/menu opened) */
  body > div#page > div#content-wrapper {
    /* Set default margin for acontent to configured open menu width. */
    margin-left: <?php print $tgs('menu_expanded_width'); ?>;
  }

  body.bilderblock-menu-closed div#menu-logo a:before {
    content: url(<?php print $homeIcon; ?>);
  }

<?php if($tgs('hover_enabled') && $tgs('menu_hover')) : ?>
  /** Dedicated menu hover effects limited to no-touch desktop devices. **/
  /* Open menu to configured width. */
  html:not(.touchevents) body.bilderblock-menu-closed.bilderblock-menu-hover div#menu:focus,
  html:not(.touchevents) body.bilderblock-menu-closed.bilderblock-menu-hover div#menu:hover,
  /* Restore inner menu content. */
  html:not(.touchevents) body.bilderblock-menu-closed.bilderblock-menu-hover div#menu:hover div#sidebar-container,
  html:not(.touchevents) body.bilderblock-menu-closed.bilderblock-menu-hover div#menu:focus div#sidebar-container,
  /* Menu switch expands, too. */
  html:not(.touchevents) body.bilderblock-menu-closed.bilderblock-menu-hover div#menu:hover div#menuswitch,
  html:not(.touchevents) body.bilderblock-menu-closed.bilderblock-menu-hover div#menu:focus div#menuswitch {
    width: <?php print $tgs('menu_expanded_width'); ?>;
  }
  /* Restore inner menu content. */
  html:not(.touchevents) body.bilderblock-menu-closed.bilderblock-menu-hover div#menu:hover div#sidebar-container,
  html:not(.touchevents) body.bilderblock-menu-closed.bilderblock-menu-hover div#menu:focus div#sidebar-container {
    overflow-y: auto;
  }
  /* Restore logo. */
  html:not(.touchevents) body.bilderblock-logo.bilderblock-menu-closed.bilderblock-menu-hover div#menu:focus div#menu-logo > a:before,
  html:not(.touchevents) body.bilderblock-logo.bilderblock-menu-closed.bilderblock-menu-hover div#menu:hover div#menu-logo > a:before {
    /* Fallback; @see dynamic.css */
    content: url(<?php print $logo; ?>);
  }
<?php endif; ?>
}

@media screen and (max-width: 960px) {
  div#menu-header div#menu-logo > a:before {
    content: url(<?php print $homeIcon; ?>);
  }
}

<?php endif;
